local uci = require "luci.model.uci".cursor()
local ds = require "luci.dispatcher"
local sys = require "luci.sys"

m = Map("iec60870-master", "", "")


s = m:section(TypedSection, "iec60870_master", translate("IEC60870 master devices"))
s.add_toggled = true
s.addremove = true
s.anonymous = true
s.sortable = false
s.dont_show_add = true
s.novaluetext = translate("No IEC60870 master added yet")
s.template = "cbi/tblsection"

function s.extedit(self, section)
	local connection_id = self.map.uci:get("iec60870-master", section, "connection_id")
	connection_id = (type(connection_id) == "string" and connection_id or "")
	return ds.build_url("admin", "services", "iec60870", "iec60870_master", connection_id)
end

function s.create(self, section, ...)
	local connection_id = sys.exec("head -c 32 /dev/urandom | md5sum | awk '{ print $1 }' | tr -d '\n'")
	local created = TypedSection.create(self, section, ...)
	self.map:set(created, "connection_id", connection_id)

	if created then
		luci.http.redirect(ds.build_url("admin/services/iec60870/iec60870_master", connection_id))
	end
end


name = s:option(DummyValue, "id", translate("Device Name"))
function name.cfgvalue(self, s)
	local set_name = self.map:get(s, "id")
	if set_name then
		if #set_name < 24 then
			return set_name
		else
			return string.sub(set_name,1,24) .. "..."
		end
	else
		return "Nameless device"
	end
end

serial_port = s:option(DummyValue, "serial_port", translate("Serial Port"))
function serial_port.cfgvalue(self, s)
	return self.map:get(s, "serial_port") or "N/A"
end

host = s:option(DummyValue, "host", translate("Host"))
function host.cfgvalue(self, s)
	local set_ip = self.map:get(s, "host")
	if set_ip then
		if #set_ip < 24 then
			return set_ip
		else
			return string.sub(set_ip,1,24) .. "..."
		end
	else
		return "N/A"
	end
end

port = s:option(DummyValue, "port", translate("Port"))
function port.cfgvalue(self, s)
	return self.map:get(s, "port") or "N/A"
end

return m
