local fs = require "nixio.fs" 

m = Map("iec60870-to-ftp", translate("IEC60870 to FTP"))

section_global = m:section(TypedSection, "global", translate("Enable/ Disable"))
section_global.anonymous = false
section_global.addremove = false
section_global.name = "global"

option_enabled = section_global:option(Flag, "enabled", translate("Enabled"),
	translate("Enable IEC60870 to FTP"))
option_enabled.rmempty=false
option_enabled.default="1"

s = m:section(TypedSection, "iec60870_ftp", translate("Configuration"))
s.anonymous = true
s.addremove = false

-- enabled = s:option(Flag, "enabled", "Enable", translate("Enable IEC60870 to FTP"))
-- enabled.default = "0"
-- enabled.rmempty = false

local_file_path = s:option(Value, "local_file_path", translate("Local File Path"),
        translate("Path to store files locally before they are uploaded to server"))
local_file_path.default = "/root/data/"

done_directory_path = s:option(Value, "done_directory_path", translate("Local File Backup Path"),
        translate("Path to store files locally after upload to remote server, leave blank if no local backup is required"))
done_directory_path.default = "/root/done/"

csv_format_type = s:option(ListValue, "csv_format_type", translate("CSV File Format"),
        translate("Type 1: File per query, Type 2: All tags in a file."))
csv_format_type:value("type_1", translate("Type 1"))
csv_format_type:value("type_2", translate("Type 2"))

protocol = s:option(ListValue, "protocol", translate("Protocol"),
        translate("Protocol that is being used."))
protocol:value("ftp", translate("FTP"))
protocol:value("sftp", translate("SFTP"))
protocol:value("scp", translate("SCP"))

--host
host = s:option(Value, "host", translate("Host IP Address"), translate("IP address or host name of the server to upload the data files"))
host.datatype = "host"

--port
port = s:option(Value, "port", translate("Port"), translate("Default port number for FTP is 21, SCP is 22"))
port.datatype = "port"
port.default = "21"

--remote path
remote_path = s:option(Value, "remote_path", translate("Remote Path"), translate("Folder path on the remote server to upload the files"))
remote_path.datatype = "string"

username = s:option(Value, "username", translate("Username"))
username.datatype = "maxlength(128)"

pass = s:option(Value, "pass", translate("Password"))
pass.password = true

--upload_interval
upload_interval = s:option(Value, "upload_interval", translate("Upload Interval (Seconds)"))
upload_interval.datatype = "range(1,86400)"

--file_creation_interval
file_creation_interval = s:option(Value, "file_creation_interval", translate("File Creation Interval (Seconds)"))
file_creation_interval.datatype = "range(1,86400)"

return m
